# Better Lists
#### By ThePyGuy

# How To use

### Adding 
This adds the item to the list

```List.add(List_name, item_to_add)```

### Removing
This removes the object from the selected list:

``list.rem(List_name, Item_to_remove)``

There are many more commands in the library.